#include <solid/acadapter.h>
#include <solid/audiointerface.h>
#include <solid/battery.h>
#include <solid/block.h>
#include <solid/button.h>
#include <solid/camera.h>
#include <solid/device.h>
#include <solid/deviceinterface.h>
#include <solid/devicenotifier.h>
#include <solid/dvbinterface.h>
#include <solid/genericinterface.h>
#include <solid/networking.h>
#include <solid/networkinterface.h>
#include <solid/opticaldisc.h>
#include <solid/opticaldrive.h>
#include <solid/portablemediaplayer.h>
#include <solid/powermanagement.h>
#include <solid/predicate.h>
#include <solid/processor.h>
#include <solid/solid_export.h>
#include <solid/solidnamespace.h>
#include <solid/storageaccess.h>
#include <solid/storagedrive.h>
#include <solid/storagevolume.h>
#include <solid/video.h>
