#ifndef SOPRANOCLIENT_SMOKE_H
#define SOPRANOCLIENT_SMOKE_H

#include <smoke.h>

// Defined in smokedata.cpp, initialized by init_sopranoclient_Smoke(), used by all .cpp files
extern "C" SMOKE_EXPORT Smoke* sopranoclient_Smoke;
extern "C" SMOKE_EXPORT void init_sopranoclient_Smoke();
extern "C" SMOKE_EXPORT void delete_sopranoclient_Smoke();

#ifndef QGLOBALSPACE_CLASS
#define QGLOBALSPACE_CLASS
class QGlobalSpace { };
#endif

#endif
