#include <soprano/asyncmodel.h>
#include <soprano/backend.h>
#include <soprano/bindingset.h>
#include <soprano/dbusclient.h>
#include <soprano/dbusexportiterator.h>
#include <soprano/dbusexportmodel.h>
#include <soprano/dbusmodel.h>
#include <soprano/dbusnodeiterator.h>
#include <soprano/dbusqueryresultiterator.h>
#include <soprano/dbusstatementiterator.h>
#include <soprano/dummymodel.h>
#include <soprano/error.h>
#include <soprano/filtermodel.h>
#include <soprano/global.h>
#include <soprano/inferencemodel.h>
#include <soprano/inferencerule.h>
#include <soprano/inferenceruleparser.h>
#include <soprano/inferenceruleset.h>
#include <soprano/iteratorbackend.h>
#include <soprano/iterator.h>
#include <soprano/literalvalue.h>
#include <soprano/localsocketclient.h>
#include <soprano/locator.h>
#include <soprano/model.h>
#include <soprano/mutexmodel.h>
#include <soprano/nao.h>
#include <soprano/node.h>
#include <soprano/nodeiterator.h>
#include <soprano/nodepattern.h>
#include <soprano/nrl.h>
#include <soprano/owl.h>
#include <soprano/parser.h>
#include <soprano/plugin.h>
#include <soprano/pluginmanager.h>
#include <soprano/queryresultiteratorbackend.h>
#include <soprano/queryresultiterator.h>
#include <soprano/rdf.h>
#include <soprano/rdfschemamodel.h>
#include <soprano/rdfs.h>
#include <soprano/readonlymodel.h>
#include <soprano/serializer.h>
#include <soprano/servercore.h>
#include <soprano/signalcachemodel.h>
#include <soprano/sil.h>
#include <soprano/simplenodeiterator.h>
#include <soprano/simplestatementiterator.h>
#include <soprano/soprano_export.h>
#include <soprano/soprano.h>
#include <soprano/sopranotypes.h>
#include <soprano/statement.h>
#include <soprano/statementiterator.h>
#include <soprano/statementpattern.h>
#include <soprano/storagemodel.h>
#include <soprano/tcpclient.h>
#include <soprano/version.h>
#include <soprano/vocabulary.h>
#include <soprano/xesam.h>
#include <soprano/xsd.h>

#if SOPRANO_VERSION >= 0x020300
#include <soprano/asyncresult.h>
#include <soprano/graph.h>
#include <soprano/languagetag.h>
#include <soprano/sopranomacros.h>
#endif

#if SOPRANO_VERSION >= 0x020401
#include <soprano/asyncquery.h>
#include <soprano/sparqlmodel.h>
#endif
