#ifndef KDECORE_SMOKE_H
#define KDECORE_SMOKE_H

#include <smoke.h>

// Defined in smokedata.cpp, initialized by init_kdecore_Smoke(), used by all .cpp files
extern "C" SMOKE_EXPORT Smoke* kdecore_Smoke;
extern "C" SMOKE_EXPORT void init_kdecore_Smoke();
extern "C" SMOKE_EXPORT void delete_kdecore_Smoke();

#ifndef QGLOBALSPACE_CLASS
#define QGLOBALSPACE_CLASS
class QGlobalSpace { };
#endif

#endif
