#include <ksettings/dispatcher.h>
#include <ksettings/dialog.h>
#include <ksettings/pluginpage.h>
#include <kemoticons.h>
#include <kemoticonstheme.h>
#include <kemoticonsprovider.h>
#include <kcmoduleinfo.h>
#include <kcmoduleloader.h>
#include <kcmultidialog.h>
#include <kcmoduleproxy.h>
#include <kpluginselector.h>
#include <kcmodulecontainer.h>
#include <kprintpreview.h>

#if KDE_IS_VERSION(4, 4, 0)
#include <kidletime.h>
#endif
