#include <kabstractfilewidget.h>
#include <kdiroperator.h>
#include <kdirselectdialog.h>
#include <kdirsortfilterproxymodel.h>
#include <kfilefiltercombo.h>
#include <kfileplacesmodel.h>
#include <kfileplacesview.h>
#include <kfiletreeview.h>
#include <kfilewidget.h>
#include <kurlnavigator.h>
#include <kfile_export.h>

#include <kdeversion.h>
#if KDE_IS_VERSION(4, 2, 0)
#include <kfilepreviewgenerator.h>
#endif
