#include <QtXml/QDomDocument>

#include <fixx11h.h>
#include <kkeyserver_x11.h>
#include <kdeui_export.h>
#include <kactioncollection.h>
#include <kaction.h>
#include <kactionmenu.h>
#include <kcodecaction.h>
#include <kfontaction.h>
#include <kfontsizeaction.h>
#include <kpastetextaction.h>
#include <krecentfilesaction.h>
#include <kselectaction.h>
#include <kstandardaction.h>
#include <ktoggleaction.h>
#include <ktoggletoolbaraction.h>
#include <ktogglefullscreenaction.h>
#include <ktoolbarlabelaction.h>
#include <ktoolbarpopupaction.h>
#include <ktoolbarspaceraction.h>
#include <kcolorutils.h>
#include <kcolorscheme.h>
#include <kcolorcollection.h>
#include <kcolorbutton.h>
#include <kcolorchoosermode.h>
#include <kcolorcombo.h>
#include <kcolordialog.h>
#include <kcolormimedata.h>
#include <kcolorvalueselector.h>
#include <khuesaturationselect.h>
#include <kconfigskeleton.h>
#include <kaboutapplicationdialog.h>
#include <kassistantdialog.h>
#include <kbugreport.h>
#include <kconfigdialog.h>
#include <kconfigdialogmanager.h>
#include <kdeprintdialog.h>
#include <kdialog.h>
#include <kedittoolbar.h>
#include <kinputdialog.h>
#include <kmessagebox.h>
#include <kmessageboxmessagehandler.h>
#include <knewpassworddialog.h>
#include <kpassworddialog.h>
#include <kpixmapregionselectordialog.h>
#include <kprogressdialog.h>
#include <ksplashscreen.h>
#include <kshortcutsdialog.h>
#include <kshortcutseditor.h>
#include <ktip.h>
#include <kfind.h>
#include <kreplace.h>
#include <kfinddialog.h>
#include <kreplacedialog.h>
#include <kfontchooser.h>
#include <kfontcombobox.h>
#include <kfontdialog.h>
#include <kfontrequester.h>
#include <kiconeffect.h>
#include <kicon.h>
#include <k3icon_p.h>
#include <kiconloader.h>
#include <kicontheme.h>
#include <kiconcache.h>
#include <klistwidget.h>
#include <klistwidgetsearchline.h>
#include <ktreewidgetsearchline.h>
#include <kextendableitemdelegate.h>
#include <kcategorizedsortfilterproxymodel.h>
#include <kcategorizedview.h>
#include <kcategorydrawer.h>
#include <kwidgetitemdelegate.h>
#include <kdialogjobuidelegate.h>
#include <kabstractwidgetjobtracker.h>
#include <kwidgetjobtracker.h>
#include <kstatusbarjobtracker.h>
#include <kuiserverjobtracker.h>
#include <kapplication.h>
#include <kuniqueapplication.h>
#include <ksessionmanager.h>
#include <kstyle.h>
#include <kstartupinfo.h>
#include <kglobalsettings.h>
#include <ksystemtrayicon.h>
#include <knotification.h>
#include <knotificationrestrictions.h>
#include <kpagedialog.h>
#include <kpagemodel.h>
#include <kpageview.h>
#include <kpagewidget.h>
#include <kpagewidgetmodel.h>
#include <kplotwidget.h>
#include <kplotpoint.h>
#include <kplotobject.h>
#include <kplotaxis.h>
#include <kshortcut.h>
#include <kstandardshortcut.h>
#include <kglobalaccel.h>
#include <kacceleratormanager.h>
#include <kgesture.h>
#include <kaccelgen.h>
#include <kcompletion.h>
#include <kcrash.h>
#include <kcursor.h>
#include <kguiitem.h>
#include <kkeyserver.h>
#include <kmanagerselection.h>
#include <knumvalidator.h>
#include <kpassivepopup.h>
#include <kpassivepopupmessagehandler.h>
#include <kpixmapcache.h>
#include <kpixmapprovider.h>
#include <kstandardguiitem.h>
#include <ksvgrenderer.h>
#include <kwallet.h>
#include <kwordwrap.h>
#include <kxerrorhandler.h>
#include <kxutils.h>
#include <kxmessages.h>
#include <kundostack.h>
#include <kactionselector.h>
#include <kanimatedbutton.h>
#include <karrowbutton.h>
#include <kdatepicker.h>
#include <kcmodule.h>
#include <kcombobox.h>
#include <kcompletionbox.h>
#include <kbuttongroup.h>
#include <kcharselect.h>
#include <kdatetable.h>
#include <kdatetimewidget.h>
#include <kdatewidget.h>
#include <kdialogbuttonbox.h>

#ifndef KDE_NO_DEPRECATED
#include <keditlistbox.h>
#endif

#include <kfadewidgeteffect.h>
#include <khbox.h>
#include <khelpmenu.h>
#include <khistorycombobox.h>
#include <kkeysequencewidget.h>
#include <klanguagebutton.h>
#include <kled.h>
#include <klineedit.h>
#include <kmainwindow.h>
#include <kmenu.h>
#include <kmenubar.h>
#include <kmultitabbar.h>
#include <knuminput.h>
#include <kpixmapregionselectorwidget.h>
#include <kpushbutton.h>
#include <krestrictedline.h>
#include <krichtextedit.h>
#include <krichtextwidget.h>
#include <kseparator.h>
#include <ksqueezedtextlabel.h>
#include <kstringvalidator.h>
#include <ktextbrowser.h>
#include <ktextedit.h>
#include <ktimezonewidget.h>
#include <ktitlewidget.h>
#include <ktabbar.h>
#include <ktabwidget.h>
#include <kruler.h>
#include <kselector.h>
#include <kshortcutwidget.h>
#include <kstatusbar.h>
#include <ktoolbar.h>
#include <kurllabel.h>
#include <kvbox.h>
#include <kxyselector.h>
#include <kwindowsystem.h>
#include <kwindowinfo.h>
#include <netwm_def.h>
#include <netwm.h>
#include <kxmlguiwindow.h>
#include <kxmlguiclient.h>
#include <kxmlguibuilder.h>
#include <kxmlguifactory.h>
#include <sonnet/dialog.h>
#include <sonnet/highlighter.h>
#include <sonnet/configdialog.h>
#include <sonnet/configwidget.h>

#if KDE_IS_VERSION(4, 2, 0)
#include <kactioncategory.h>
#include <kfilterproxysearchline.h>
#include <kglobalshortcutinfo.h>
#include <kglobalshortcutinfo_p.h>
#include <kcapacitybar.h>
#include <sonnet/dictionarycombobox.h>
#endif

#if KDE_IS_VERSION(4, 3, 0)
#include <kmodifierkeyinfo.h>
#endif

#if KDE_IS_VERSION(4, 4, 0)
#include <kselectionproxymodel.h>
#include <kstatusnotifieritem.h>
#include <kpixmapsequence.h>
#include <kpixmapsequenceoverlaypainter.h>
#include <kpixmapsequencewidget.h>
#endif
