#ifndef PLASMA_SMOKE_H
#define PLASMA_SMOKE_H

#include <smoke.h>

extern "C" SMOKE_EXPORT Smoke* plasma_Smoke;
extern "C" SMOKE_EXPORT void init_plasma_Smoke();
extern "C" SMOKE_EXPORT void delete_plasma_Smoke();

#ifndef QGLOBALSPACE_CLASS
#define QGLOBALSPACE_CLASS
class QGlobalSpace { };
#endif

#endif
