#include <kdeversion.h>
#if KDE_IS_VERSION(4, 4, 0)
#include <knewstuff3/downloaddialog.h>
#include <knewstuff3/entry.h>
#include <knewstuff3/knewstuff_export.h>
#include <knewstuff3/knewstuffaction.h>
#include <knewstuff3/knewstuffbutton.h>
#include <knewstuff3/uploaddialog.h>
#endif
