#ifndef KNEWSTUFF2_SMOKE_H
#define KNEWSTUFF2_SMOKE_H

#include <smoke.h>

// Defined in smokedata.cpp, initialized by init_knewstuff2_Smoke(), used by all .cpp files
extern "C" SMOKE_EXPORT Smoke* knewstuff2_Smoke;
extern "C" SMOKE_EXPORT void init_knewstuff2_Smoke();
extern "C" SMOKE_EXPORT void delete_knewstuff2_Smoke();

#ifndef QGLOBALSPACE_CLASS
#define QGLOBALSPACE_CLASS
class QGlobalSpace { };
#endif

#endif
